# Black Belt

Black belt is collection of scripts, tools and guidelines used for developing projects The Apiary Way.

## Development Installation

`virtualenv` assumed (`sudo pip virtualenv`)

```
virtualenv venv
source venv/bin/activate
pip install paver
pip install -r requirements-development.txt
paver develop
paver test
```



## Installation & Usage

Please refer to [The Black Belt Documentation](http://black-belt.readthedocs.org/). 
